#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'moc-shortcut-manager.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "libgui/src/moc-shortcut-manager.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'moc-shortcut-manager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__enter_shortcut_t {
    QByteArrayData data[4];
    char stringdata0[69];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__enter_shortcut_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__enter_shortcut_t qt_meta_stringdata_octave__enter_shortcut = {
    {
QT_MOC_LITERAL(0, 0, 22), // "octave::enter_shortcut"
QT_MOC_LITERAL(1, 23, 22), // "handle_direct_shortcut"
QT_MOC_LITERAL(2, 46, 0), // ""
QT_MOC_LITERAL(3, 47, 21) // "handle_shift_modifier"

    },
    "octave::enter_shortcut\0handle_direct_shortcut\0"
    "\0handle_shift_modifier"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__enter_shortcut[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       3,    1,   27,    2, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void octave::enter_shortcut::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        enter_shortcut *_t = static_cast<enter_shortcut *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->handle_direct_shortcut((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 1: _t->handle_shift_modifier((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject octave::enter_shortcut::staticMetaObject = {
    { &QLineEdit::staticMetaObject, qt_meta_stringdata_octave__enter_shortcut.data,
      qt_meta_data_octave__enter_shortcut,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::enter_shortcut::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::enter_shortcut::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__enter_shortcut.stringdata0))
        return static_cast<void*>(this);
    return QLineEdit::qt_metacast(_clname);
}

int octave::enter_shortcut::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QLineEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_octave__shortcut_manager_t {
    QByteArrayData data[6];
    char stringdata0[118];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__shortcut_manager_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__shortcut_manager_t qt_meta_stringdata_octave__shortcut_manager = {
    {
QT_MOC_LITERAL(0, 0, 24), // "octave::shortcut_manager"
QT_MOC_LITERAL(1, 25, 21), // "handle_double_clicked"
QT_MOC_LITERAL(2, 47, 0), // ""
QT_MOC_LITERAL(3, 48, 16), // "QTreeWidgetItem*"
QT_MOC_LITERAL(4, 65, 24), // "shortcut_dialog_finished"
QT_MOC_LITERAL(5, 90, 27) // "shortcut_dialog_set_default"

    },
    "octave::shortcut_manager\0handle_double_clicked\0"
    "\0QTreeWidgetItem*\0shortcut_dialog_finished\0"
    "shortcut_dialog_set_default"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__shortcut_manager[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   29,    2, 0x09 /* Protected */,
       4,    1,   34,    2, 0x09 /* Protected */,
       5,    0,   37,    2, 0x09 /* Protected */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,

       0        // eod
};

void octave::shortcut_manager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        shortcut_manager *_t = static_cast<shortcut_manager *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->handle_double_clicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->shortcut_dialog_finished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->shortcut_dialog_set_default(); break;
        default: ;
        }
    }
}

const QMetaObject octave::shortcut_manager::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_octave__shortcut_manager.data,
      qt_meta_data_octave__shortcut_manager,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::shortcut_manager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::shortcut_manager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__shortcut_manager.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int octave::shortcut_manager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
